@@ -5,13 +5,13 @@ FacetGrid <- proto(Facet, {
 		gTree(children = gList(
 			rectGrob(0, 1, width=0.95, height=0.05, hjust=0, vjust=1, gp=gpar(fill="grey60", col=NA)),
 			rectGrob(0.95, 0.95, width=0.05, height=0.95, hjust=0, vjust=1, gp=gpar(fill="grey60", col=NA)),
-			segmentsGrob(c(0, 0.475), c(0.475, 0), c(1, 0.475), c(0.475, 1))		
+			segmentsGrob(c(0, 0.475), c(0.475, 0), c(1, 0.475), c(0.475, 1))
 		))
 	}
 	
 	new <- function(., facets = . ~ ., margins = FALSE) {
 		if (inherits(facets, "formula")) facets <- deparse(facets) 
-		proto(., facets=facets, margins=margins)
+		.$proto(facets=facets, margins=margins)
 	}
 	
 	conditionals <- function(.) {
