@@ -30,8 +30,8 @@ guides_basic <- function(plot, scales, coordinates) {
   nr <- nrow(gm)
   nc <- ncol(gm)
 
-	axes_v <- matrix(lapply(1:nr, function(n) ggname("yaxis", guides$y)), ncol=1)
-	axes_h <- matrix(lapply(1:nc, function(n) ggname("xaxis", guides$x)), nrow=1)
+	axes_v <- matrix(lapply(1:nr, function(n) ggname(paste("yaxis", n, sep="-"), guides$y)), ncol=1)
+	axes_h <- matrix(lapply(1:nc, function(n) ggname(paste("xaxis", n, sep="-"), guides$x)), nrow=1)
 	
 	foreground <- matrix(rep(list(coordinates$guide_foreground(plot)), nc * nr), ncol = nc)
 	dim(foreground) <- dim(gm)
