@@ -3,7 +3,7 @@ ScaleSize <- proto(ScaleContinuous, expr={
 	.input <- .output  <- "size"
 	
 	new <- function(., name=NULL, to=c(1, 5), guide="point") {
-		proto(., name=name, .range=to, .grob=guide)
+		.$proto(name=name, .range=to, .grob=guide)
 	}
 	
 	guide_legend_geom <- function(.) Geom$find(.$.grob)
