@@ -1,13 +1,23 @@
 StatSmooth <- proto(Stat, {
 	calculate <- function(., data, scales, method=loess, formula=y~x, se = TRUE, n=80, fullrange=FALSE, xseq = NULL, level=0.95, ...) {
 		if (nrow(data) < 2) return(NULL)
+		if (length(unique(data$x)) == 1) {
+			stop("geom_smooth: Only one unique x value in this group.  Maybe you want aes(group = 1)?", call. = FALSE)
+		}
+		
 		if (is.null(data$weight)) data$weight <- 1
 		
 		if (is.null(xseq)) {
-			range <- if (fullrange) scales$get_scales("x")$frange() else range(data$x, na.rm=TRUE)	
-			xseq <- seq(range[1], range[2], length=n)
+			if (is.factor(data$x)) {
+				xseq <- if (fullrange) scales$get_scales("x")$domain() else levels(data$x)
+			} else {
+				range <- if (fullrange) scales$get_scales("x")$frange() else range(data$x, na.rm=TRUE)	
+				xseq <- seq(range[1], range[2], length=n)
+			}
+			
 		}
 		if (is.character(method)) method <- match.fun(method)
+		if (identical(method,loess) && is.factor(data$x)) stop("geom_smooth: loess smooth does not work with categorical data.  Maybe you want method=lm?", call.=FALSE)
 		
 		params <- list(...)
 		model.params <- params[intersect(names(formals(method)), names(params))]
